The PyDy source code is spread across both the SymPy and PyDy repositories. The
two projects are very intimately tied together in terms of development. Much of
our development practices come from SymPy's methods so reading their
documentation for contributing is the best place to start:

https://docs.sympy.org/latest/contributing/introduction-to-contributing.html

Style
=====

Code written in Python should roughly adhere to PEP8:

http://www.python.org/dev/peps/pep-0008/.

There are some exceptions, such as naming of variables. Use your best judgment.
